# CW Inference in Python

A Python module for performing Bayesian inference for continuous gravitational-wave signals from pulsars

* [Documentation](https://cwinpy.readthedocs.io)

[![Documentation Status](https://readthedocs.org/projects/cwinpy/badge/?version=latest)](https://cwinpy.readthedocs.io/en/latest/?badge=latest)
[![Build Status](https://travis-ci.org/cwinpy/cwinpy.svg?branch=master)](https://travis-ci.org/cwinpy/cwinpy)
[![codecov](https://codecov.io/gh/cwinpy/cwinpy/branch/master/graph/badge.svg)](https://codecov.io/gh/cwinpy/cwinpy)